# mojave
## Tooig Operating System

I deleted the previous documentation. I'll fix it. And then we'll go from there.
let's get started 

## How to build
### Requirements
- A Linux system
- A cross-compiler
- A cross-compiler for the kernel
- A cross-compiler for the bootloader
- A cross-compiler for the libc
- A cross-compiler for the libk
- A cross-compiler for the libgfx
- A cross-compiler for the libio
- A cross-compiler for the libstd
- A cross-compiler for the libtest
- A cross-compiler for the libutils
- A cross-compiler for the libvga
- A cross-compiler for the libwindow
- A cross-compiler for the libx86
- A cross-compiler for the libx86emu
